migration

package
v0.3.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DetectLegacy

func DetectLegacy() (string, bool)

DetectLegacy checks if the legacy ~/.finfocus directory exists.

func GetNewPath

func GetNewPath() (string, error)

GetNewPath returns the path to the new ~/.finfocus directory.

func RunMigration

func RunMigration(out io.Writer, in io.Reader) error

RunMigration handles the interactive migration from legacy to new configuration.

func SafeCopy

func SafeCopy(src, dst string) error

SafeCopy recursively copies the source directory to the destination. It preserves original data by performing a copy instead of a move.

Types

This section is empty.

Jump to