version

package
v0.3.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package version provides build version and metadata information for finfocus. Version information is embedded at build time via ldflags from the CI/CD pipeline.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetBuildDate

func GetBuildDate() string

GetBuildDate returns the build date.

func GetGitCommit

func GetGitCommit() string

GetGitCommit returns the git commit hash.

func GetVersion

func GetVersion() string

GetVersion returns the version string.

Types

This section is empty.

Jump to